import { Routes, Route, Navigate, useNavigate } from 'react-router-dom'
import { useDispatch } from 'react-redux'
import { setAccessToken, setUserInfo, setSelectInfo } from "./business/userSlice.js"
import { useCookies } from 'react-cookie';
import LoginPage from './LoginPage';
import MainPage from './MainPage';
import yzs from "./business/request.js";

function App() {
  const dispatch = useDispatch();
  const navigate = useNavigate();
  const [cookies, setCookie, removeCookie] = useCookies(['accessToken']);

  if (cookies.accessToken) {
    dispatch(setAccessToken(cookies.accessToken));
    yzs.get_user_info(yzs.uniqueDeviceIdentifier(), cookies.accessToken).then(info => {
      dispatch(setUserInfo(info));
      yzs.user_select(yzs.uniqueDeviceIdentifier(), cookies.accessToken).then(info => {
        dispatch(setSelectInfo(info));
      });
    }).catch(error => {
      console.log(error)
      if (error.returnCode === "uc_0106") {
        removeCookie("accessToken");
        navigate("/login");
      }
    });
  }
  return (
    <div>
      <Routes>
        <Route exact path="/" element={cookies.accessToken ? <MainPage /> : <Navigate to="/login" />} />
        <Route exact path="/login" element={<LoginPage />} />
      </Routes>
    </div>
  );
}

export default App;
