import { MenuItem, Select, IconButton, Typography, Stack, Container } from "@mui/material"
import { useSelector, useDispatch } from 'react-redux'
import { useEffect, useRef, useState, useCallback } from "react";
import pauseIcon from "./assets/play.png";
import playIcon from "./assets/pause.png";
import downloadIcon from "./assets/download.png";
import { setCurrentTime, togglePauseState } from "./business/recorderSlice.js"
import ProgressBar from "./components/ProgressBar";

const durationFormat = (time) => {
    if (isNaN(time)) return "00:00:00";
    time = parseInt(time);
    let second = parseInt(time % 60);
    let minute = parseInt((time / 60) % 60);
    let hour = parseInt(time / 3600);
    return hour.toString().padStart(2, '0') + ":" + minute.toString().padStart(2, '0') + ":" + second.toString().padStart(2, '0');
}

export default function ({ width, currentTime }) {
    const dispatch = useDispatch();
    const [duration, setDuration] = useState(0);    // 秒，有小数点
    const currentIndex = useSelector(state => state.recorder.currentIndex);
    const recordList = useSelector(state => state.recorder.list);
    const currentBlob = useSelector(state => state.recorder.currentBlob);
    const currentWaveData = useSelector(state => state.recorder.currentWaveData);
    const pause = useSelector(state => state.recorder.pause);
    const player = useRef(null);
    useEffect(() => {
        player.current.url = currentBlob
        console.log(player.current.url);
    }, [currentBlob]);

    const toggleState = () => {
        if (pause) {
            player.current.play();
        } else {
            player.current.pause();
        }
        dispatch(togglePauseState());
    };

    const onDurationChange = (event) => {
        setDuration(player.current.duration);
    }
    const onTimeUpdate = (event) => {
        dispatch(setCurrentTime(player.current.currentTime));
    }

    const seekRecord = (second) => {
        player.current.currentTime = second;
    }

    const onChange = (event) => {
        player.current.playbackRate = event.target.value;
    };

    return <Stack sx={{
        position: "sticky",
        top: 48,
        backgroundColor: "#FAFAFA",
    }} >
        <Container disableGutters maxWidth={false} sx={{
            height: 60,
            display: "flex",
            alignItems: "center",
        }}>
            <Typography variant="h6" sx={{ flexGrow: 1 }} >{recordList.length > 0 ? recordList.at(currentIndex).editName : ""}</Typography>
            <IconButton onClick={toggleState}>
                <img src={downloadIcon} />
            </IconButton>
        </Container>

        <div style={{
            display: "flex",
            backgroundColor: "#E6EAEC",
            height: "70px",
            width: "100%",
        }}>
            <IconButton onClick={toggleState} sx={{ width: 70, height: 70 }}>
                <img src={pause ? pauseIcon : playIcon} />
            </IconButton>

            <audio ref={player} src={currentBlob} onDurationChange={onDurationChange} onTimeUpdate={onTimeUpdate} />
            <ProgressBar width={isNaN(width) ? 0 : (width - 70 - 90)} duration={Math.ceil(duration * 1000)}
                currentTime={currentTime} playing={!pause} seek={seekRecord}
                waveData={currentWaveData}
            />
            <Select
                defaultValue={1.0}
                onChange={onChange}
                sx={{ width: 90, height: 70 }}
            >
                <MenuItem value={0.5}>0.5X</MenuItem>
                <MenuItem value={1.0}>1.0X</MenuItem>
                <MenuItem value={1.25}>1.25X</MenuItem>
                <MenuItem value={1.5}>1.5X</MenuItem>
                <MenuItem value={2.0}>2.0X</MenuItem>
            </Select>
        </div>

        <Container maxWidth={false} sx={{ backgroundColor: "#F2F4F5" }}>
            <Typography sx={{ color: "#6B7486" }}>  {durationFormat(currentTime)} / {durationFormat(duration)}</Typography>
        </Container>
    </Stack>
}