import React from 'react';
import { useSelector, useDispatch } from 'react-redux'
import Box from '@mui/material/Box';
import Drawer from '@mui/material/Drawer';
import List from '@mui/material/List';
import ListItem from '@mui/material/ListItem';
import ListItemButton from '@mui/material/ListItemButton';
import ListItemText from '@mui/material/ListItemText';
import Typography from '@mui/material/Typography';
import Toolbar from '@mui/material/Toolbar';
import { setCurrentIndex } from "./business/recorderSlice.js"
import AccessTimeFilledIcon from '@mui/icons-material/AccessTimeFilled';

const drawerWidth = 240;

export default function ({ open, fetchRecord }) {
    const dispatch = useDispatch();
    const accessToken = useSelector(state => state.user.accessToken);
    const currentIndex = useSelector(state => state.recorder.currentIndex);
    const recordList = useSelector(state => state.recorder.list);
    const onSelected = (event, index) => {
        console.log("onSelected", index, recordList.at(index).transResultUrl)
        dispatch(setCurrentIndex(index));
        fetchRecord(accessToken, recordList.at(index));
    }
    return <Drawer
        variant="persistent"
        anchor="left"
        open={open}
        sx={{
            width: drawerWidth,
            flexShrink: 0,
            '& .MuiDrawer-paper': {
                width: drawerWidth,
                boxSizing: 'border-box',
            },
        }}
    >
        <Toolbar variant="dense" />
        <Box sx={{ overflow: 'auto' }}>
            <List>
                {recordList === undefined ? <React.Fragment /> : recordList.map((item, index) => (
                    <ListItem key={index} disablePadding>
                        <ListItemButton selected={currentIndex === index} onClick={(event) => onSelected(event, index)}>
                            <ListItemText primary={item.editName} secondary={
                                <React.Fragment>
                                    <Typography component="span" variant="body1">{item.content.slice(0, 50) + '......'}</Typography>
                                    <br />
                                    <AccessTimeFilledIcon sx={{ fontSize: 12 }} />
                                    <Typography component="span" variant="body2"> 更新于 {new Date(item.createTime).toLocaleString()}</Typography>
                                </React.Fragment>
                            } />
                        </ListItemButton>
                    </ListItem>
                ))}
            </List>
        </Box>
    </Drawer>
}